16.22. cdist-type__consul_reload(7) — cdist 6.1.1 documentation

# 16.22. cdist-type__consul_reload(7)

## 16.22.1. NAME

cdist-type__consul_reload - Reload consul

## 16.22.2. DESCRIPTION

Reload consul after configuration changes.

## 16.22.3. REQUIRED PARAMETERS

None.

## 16.22.4. OPTIONAL PARAMETERS

None.

## 16.22.5. EXAMPLES

    __consul_reload

## 16.22.6. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>

## 16.22.7. COPYING

Copyright (C) 2015 Steven Armstrong. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.